@@ -197,8 +197,13 @@ async def node_view_profile_report(data_id: str):
 
 def run():
     import socket
+    from dtale_desktop import dtale_app
+
+    if not settings.DISABLE_OPEN_BROWSER:
+        launch_browser_opener(f"http://{settings.HOST}:{settings.PORT}")
+
+    dtale_app.run()
 
-    launch_browser_opener(f"http://{settings.HOST}:{settings.PORT}")
     uvicorn.run(
         app, host=socket.gethostbyname(settings.HOST), port=settings.PORT, debug=True
     )
