@@ -3,6 +3,8 @@ Environment variables that can be used to configure settings:
 - DTALEDESKTOP_HOST
 - DTALEDESKTOP_PORT
 - DTALEDESKTOP_DTALE_PORT
+- DTALEDESKTOP_HOST_NAME
+    used for building links, might be necessary if you're running this in a container.
 - DTALEDESKTOP_ROOT_DIR:
     path, the location where all persistent data (loaders, cached data, etc.) will be stored.
     By default this is ~/.dtaledesktop
@@ -17,6 +19,8 @@ Environment variables that can be used to configure settings:
 - DTALEDESKTOP_DISABLE_PROFILE_REPORTS:
     "true" if the "Profile" option (which builds a pandas_profiling report) should not be shown.
     This is resource-intensive and currently a bit buggy (it launches a subprocess).
+- DTALEDESKTOP_DISABLE_OPEN_BROWSER
+    "true" if browser should not open upon startup
 """
 import os
 import socket
@@ -36,9 +40,11 @@ class _Settings:
     DISABLE_EDIT_DATA_SOURCES: bool
     DISABLE_EDIT_LAYOUT: bool
     DISABLE_PROFILE_REPORTS: bool
+    DISABLE_OPEN_BROWSER: bool
     HOST: str
     PORT: int
     DTALE_PORT: Optional[int]
+    HOST_NAME: str
 
     _instance = _SENTINEL
 
@@ -48,6 +54,7 @@ class _Settings:
         self._instance = self
 
         self._HOST = os.getenv("DTALEDESKTOP_HOST", None)
+        self._HOST_NAME = os.getenv("DTALEDESKTOP_HOST_NAME", None)
 
         try:
             self._PORT = int(os.getenv("DTALEDESKTOP_PORT"))
@@ -80,6 +87,9 @@ class _Settings:
         self.DISABLE_PROFILE_REPORTS = (
             os.getenv("DTALEDESKTOP_DISABLE_PROFILE_REPORTS", "").lower() == "true"
         )
+        self.DISABLE_OPEN_BROWSER = (
+            os.getenv("DTALEDESKTOP_DISABLE_OPEN_BROWSER", "").lower() == "true"
+        )
 
     @property
     def HOST(self) -> str:
@@ -99,6 +109,10 @@ class _Settings:
             sock.close()
         return self._PORT
 
+    @property
+    def HOST_NAME(self) -> str:
+        return self._HOST_NAME or self.HOST
+
     class Serialized(BaseApiModel):
         disable_add_data_sources: bool
         disable_edit_data_sources: bool
